netapp_ontap.models.nfs_service_transport API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_transport`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceTransportSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceTransport object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `rdma_enabled: bool GET POST PATCH`

    Specifies whether RDMA transport is enabled for the NFS server.

  `tcp_enabled: bool GET POST PATCH`

    Specifies whether TCP transports are enabled on the server.

  `tcp_max_transfer_size: Size GET POST PATCH`

    Specifies the maximum transfer size in bytes, that the storage system negotiates with the client for TCP transport of data for NFSv3 and NFSv4.x protocols. The range is 8192 to 1048576.

    Example: 16384

  `udp_enabled: bool GET POST PATCH`

    Specifies whether UDP transports are enabled on the server.